@@ -19,22 +19,24 @@
  */
 
 #include "extractortest.h"
+#include "config.h"
 
 #include <QTest>
 #include <QProcess>
+#include <QTemporaryFile>
 #include <QTemporaryDir>
-#include <QFile>
 #include <QTextStream>
 #include <QStandardPaths>
 #include <QDebug>
+#include <QDir>
 
 #include "xapiandatabase.h"
+#include "xapiandocument.h"
 
 void ExtractorTest::test()
 {
     QTemporaryDir dbDir;
-    dbDir.setAutoRemove(false);
-    const QString fileUrl = dbDir.path() + "/testFile.txt";
+    const QString fileUrl = dbDir.path() + QLatin1String("/testFile.txt");
 
     QFile file(fileUrl);
     file.open(QIODevice::WriteOnly);
@@ -42,10 +44,10 @@ void ExtractorTest::test()
     stream << "Some words";
     file.close();
 
-    QString exe = QStandardPaths::findExecutable("baloo_file_extractor");
+    QString exe = QStandardPaths::findExecutable(QLatin1String("baloo_file_extractor"));
 
     QStringList args;
-    args << fileUrl << "--db" << dbDir.path() << "--ignoreConfig";
+    args << fileUrl << QLatin1String("--db") << dbDir.path() << QLatin1String("--ignoreConfig");
 
     QProcess process;
     process.start(exe, args);
@@ -64,13 +66,51 @@ void ExtractorTest::test()
         words << QString::fromUtf8(str.c_str(), str.length());
     }
 
-    QVERIFY(words.contains("some"));
-    QVERIFY(words.contains("words"));
-    QVERIFY(words.contains("testfile"));
-    QVERIFY(words.contains("txt"));
-    QVERIFY(words.contains("Z2"));
+    QVERIFY(words.contains(QLatin1String("some")));
+    QVERIFY(words.contains(QLatin1String("words")));
+    QVERIFY(words.contains(QLatin1String("testfile")));
+    QVERIFY(words.contains(QLatin1String("txt")));
+    QVERIFY(words.contains(QLatin1String("Z2")));
 }
 
-QTEST_MAIN(ExtractorTest)
+void ExtractorTest::testFileDeletion()
+{
+    QTemporaryDir dbDir;
 
-#include "extractortest.moc"
+    Baloo::XapianDatabase xapDb(dbDir.path());
+    Baloo::XapianDocument doc;
+    doc.indexText("Random text which does not matter");
+    xapDb.replaceDocument(1, doc);
+    xapDb.commit();
+
+    QCOMPARE(xapDb.db()->get_doccount(), static_cast<uint>(1));
+    try {
+        Xapian::Document doc = xapDb.db()->get_document(1);
+        QCOMPARE(doc.termlist_count(), static_cast<uint>(6));
+    }
+    catch (...) {
+        QVERIFY2(false, "Document not committed");
+    }
+
+    QString exe = QStandardPaths::findExecutable(QLatin1String("baloo_file_extractor"));
+
+    QStringList args;
+    args << "1" << QLatin1String("--db") << dbDir.path() << QLatin1String("--ignoreConfig");
+
+    QProcess process;
+    process.start(exe, args);
+    QVERIFY(process.waitForFinished(10000));
+
+    // The document should have been deleted from the db
+    xapDb.db()->reopen();
+    QCOMPARE(xapDb.db()->get_doccount(), static_cast<uint>(0));
+    try {
+        Xapian::Document doc = xapDb.db()->get_document(1);
+        QVERIFY2(false, "The document should no longer exist");
+    }
+    catch (...) {
+    }
+}
+
+
+QTEST_MAIN(ExtractorTest)
